@@ -1,21 +1,10 @@
 /*  -*- c++ -*-
-    Copyright 2008 Thomas McGuire <Thomas.McGuire@gmx.net>
-    Copyright 2008 Edwin Schepers <yez@familieschepers.nl>
-    Copyright 2008 Tom Albers <tomalbers@kde.nl>
-    Copyright 2004 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2008 Thomas McGuire <Thomas.McGuire@gmx.net>
+    SPDX-FileCopyrightText: 2008 Edwin Schepers <yez@familieschepers.nl>
+    SPDX-FileCopyrightText: 2008 Tom Albers <tomalbers@kde.nl>
+    SPDX-FileCopyrightText: 2004 Marc Mutz <mutz@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef KIDENTITYMANAGER_SIGNATURECONFIGURATOR_H
@@ -27,86 +16,79 @@
 
 using KIdentityManagement::Signature;
 
-namespace KIdentityManagement {
+namespace KIdentityManagement
+{
 /**
-  * This widget gives an interface so users can edit their signature.
-  * You can set a signature via setSignature(), let the user edit the
-  * signature and when done, read the signature back.
-  */
+ * This widget gives an interface so users can edit their signature.
+ * You can set a signature via setSignature(), let the user edit the
+ * signature and when done, read the signature back.
+ */
 class KIDENTITYMANAGEMENT_EXPORT SignatureConfigurator : public QWidget
 {
     Q_OBJECT
 public:
     /**
-      * Constructor
-      */
+     * Constructor
+     */
     explicit SignatureConfigurator(QWidget *parent = nullptr);
 
     /**
-      * destructor
-      */
+     * destructor
+     */
     ~SignatureConfigurator() override;
 
     /**
-      * Enum for the different viewmodes.
-      */
-    enum ViewMode {
-        ShowCode, ShowHtml
-    };
+     * Enum for the different viewmodes.
+     */
+    enum ViewMode { ShowCode, ShowHtml };
 
     /**
-      * Indicated if the user wants a signature
-      */
+     * Indicated if the user wants a signature
+     */
     Q_REQUIRED_RESULT bool isSignatureEnabled() const;
 
     /**
-      * Use this to activate the signature.
-      */
+     * Use this to activate the signature.
+     */
     void setSignatureEnabled(bool enable);
 
     /**
-      * This returns the type of the signature,
-      * so that can be Disabled, Inline, fromFile, etc.
-      */
+     * This returns the type of the signature,
+     * so that can be Disabled, Inline, fromFile, etc.
+     */
     Q_REQUIRED_RESULT Signature::Type signatureType() const;
 
     /**
-      * Set the signature type to @p type.
-      */
+     * Set the signature type to @p type.
+     */
     void setSignatureType(Signature::Type type);
 
     /**
-      * Returns the inline text, only useful
-      * when this is the appropriate Signature::Type
-      */
-    Q_REQUIRED_RESULT QString inlineText() const;
-
-    /**
-      * Make @p text the text for the signature.
-      */
+     * Make @p text the text for the signature.
+     */
     void setInlineText(const QString &text);
 
     /**
-      * Returns the file url which the user wants
-      * to use as a signature.
-      */
+     * Returns the file url which the user wants
+     * to use as a signature.
+     */
     Q_REQUIRED_RESULT QString filePath() const;
 
     /**
-      * Set @p url for the file url part of the
-      * widget.
-      */
+     * Set @p url for the file url part of the
+     * widget.
+     */
     void setFileURL(const QString &url);
 
     /**
-      * Returns the url of the command which the
-      * users wants to use as signature.
-      */
+     * Returns the url of the command which the
+     * users wants to use as signature.
+     */
     Q_REQUIRED_RESULT QString commandPath() const;
 
     /**
-      * Sets @p url as the command to execute.
-      */
+     * Sets @p url as the command to execute.
+     */
     void setCommandURL(const QString &url);
 
     /**
